@@ -10,6 +10,7 @@ our @ISA     = qw(Exporter);
 our @EXPORT  = qw(
                   for_all_hosts
                   get_filepath_current
+                  get_hostclass
                   get_site
                   get_sitegroup
                   get_hostname
@@ -65,6 +66,14 @@ sub get_sitegroup {
     return get_file_string($hostid, "/siteinfo/sitegroup");
 }
 
+#
+# Return the hostclass string
+#
+sub get_hostclass {
+    my $hostid = shift;
+    return get_file_string($hostid, "/siteinfo/hostclass");
+}
+
 #
 # Return the hostname string
 #
